@@ -4,7 +4,5 @@
 from .econtools import *
 from .generic import *
 from .plots import *
-from .njitted import *
 from .optimize import *
-from .linalg import *
 from .datatools import *
